@@ -17,10 +17,30 @@ from random import randrange
 os.environ['TF_CPP_MIN_LOG_LEVEL'] = '3'
 
 SOURCES = [
-    'tensorflow', 'keras', 'torch', 'fastai', 'mxnet', 'pretrainedmodels', 'mmf'
+    'tensorflow', 'keras', 'torchvision', 'fastai', 'mxnet', 'pretrainedmodels',
+    'mmf'
 ]
 
-IMPLEMENTED_SOURCES = ['keras', 'torch', 'tensorflow']
+IMPLEMENTED_SOURCES = ['keras', 'torchvision', 'tensorflow']
+
+OBJECT_DETECTION_COMPATIBILITY = {
+    'fasterrcnn_resnet50_fpn': {
+        'VOCDetection/2007',
+        'VOCDetection/2008',
+        'VOCDetection/2010',
+        'VOCDetection/2011',
+        'VOCDetection/2012',
+        'CelebA',
+        'coco',
+        'flic',
+        'kitti',
+        'open_images_challenge2019_detection',
+        'open_images_v4',
+        'wider_face',
+    },
+    'keypointrcnn_resnet50_fpn': {},
+    'maskrcnn_resnet50_fpn': {'coco'}
+}
 
 IMAGE_MINS = {
     'InceptionV3': 75,
@@ -52,6 +72,15 @@ IMAGE_MINS = {
 
 PIXELS_CLASSES = {'lost_and_found': 44, 'cityscapes': 35, 'scene_parse150': 150}
 
+# In keypoint detection there are models that require a box param for training
+KEYPOINT_REQUIRE_BOX = ['keypointrcnn_resnet50_fpn']
+KEYPOINT_REQUIRE_VISIBILTY = ['keypointrcnn_resnet50_fpn']
+
+
+def get_implemented_sources(sources):
+  implemented = filter(lambda s: s in IMPLEMENTED_SOURCES, sources)
+  return list(implemented)
+
 
 def split_sources(sources):
   '''Temporal function to split sources in two groups: those that are already
@@ -163,7 +192,19 @@ def map_source_metadata() -> dict:
 
   for source in sources:
     wrapper = importlib.import_module('sotaai.cv.' + source + '_wrapper')
-    items_breakdown[source] = wrapper.SOURCE_METADATA
+
+    model_tasks = []
+    dataset_tasks = []
+    if hasattr(wrapper, 'MODELS'):
+      model_tasks = list(wrapper.MODELS.keys())
+    if hasattr(wrapper, 'DATASETS'):
+      dataset_tasks = list(wrapper.DATASETS.keys())
+    tasks = list(set(model_tasks + dataset_tasks))
+
+    metadata = dict(wrapper.SOURCE_METADATA)
+    metadata['tasks'] = tasks
+
+    items_breakdown[source] = metadata
 
   return items_breakdown
 
@@ -592,7 +633,7 @@ def get_source_from_dataset(dataset) -> str:
     if len(dataset) == 2 and isinstance(dataset[0], np.ndarray):
       # Keras dataset objects are numpy.ndarray tuples.
       source = 'keras'
-  elif 'torch' in obj_type:
+  elif 'torchvision' in obj_type:
     source = 'torchvision'
   else:
     # Dataset source's name is read from the dataset type.
@@ -930,3 +971,39 @@ def get_input_shape_min(model_name: str) -> tuple:
     return (IMAGE_MINS[model_name], IMAGE_MINS[model_name])
   else:
     return (None, None)
+
+
+def get_require_box(model_name: str) -> bool:
+  ''' Returns if a model requires a box param for keypoint detection
+
+  Args:
+    model_name: the model name as string
+
+  Returns:
+    A boolean, indicating whether a model requires box parame or not
+  '''
+  return bool(model_name in KEYPOINT_REQUIRE_BOX)
+
+
+def get_keypoint_visibility(model_name: str) -> bool:
+  ''' Returns if a model requires a box param for keypoint detection
+
+  Args:
+    model_name: the model name as string
+
+  Returns:
+    A boolean, indicating whether a model requires visibility along with keypoints
+  '''
+  return bool(model_name in KEYPOINT_REQUIRE_VISIBILTY)
+
+
+def get_keypoints_normalized(dataset_name, source):
+  if source == 'tensorflow':
+
+    if dataset_name == 'aflw2k3d':
+      return True
+    elif dataset_name == 'celeb_a':
+
+      return False
+    elif dataset_name == 'the300w_lp':
+      return True
